package com.google.appengine.api.datastore;

import java.io.Serializable;

import com.google.gwt.user.client.rpc.IsSerializable;

/**
 * Simple (very simple) implementation of Key.  This implemenation is intended to be used as a data container, and 
 * not a logic implementing bean.  Some methods are not provided in this implementation, other are provided and throw 
 * exception.
 * The supported methods are:
 * <code>
 * compareTo(Key key)
 * equals(Object obj)
 * getId()
 * getName()
 * getAppId()
 * getKind()
 * </code>
 * @author Bryce Cottam 
 *
 */
public class Key implements Serializable, Comparable<Key>, IsSerializable
{
	
	private static final long serialVersionUID = 1L;
	
	private Integer hash;
	
	String encodedValue;
	String appId;
	String kind;
	String name;
	long id = 0;
	
	Key(String encodedValue)
	{
		if (encodedValue == null)
		{
			throw new IllegalArgumentException("encodedValue cannot be null");
		}
		
		this.encodedValue = encodedValue;
	}
	
	public int compareTo(Key key)
	{
		// TODO: implement me...
		return 0;
	}
	
	public int hashCode()
	{
		if (hash == null)
		{
			hash = encodedValue.hashCode();
		}
		
		return hash;
	}
	
	public boolean equals(Object obj)
	{
		if (this == obj)
		{
			return true;
		}
		
		boolean eq = false;
		
		if (obj instanceof Key)
		{
			Key that = (Key) obj;
			eq = this.encodedValue.equals(that.encodedValue);
		}
		
		return eq;
	}
	
	public String getAppId()
	{
		return appId;
	}
	
	public String getKind()
	{
		return kind;
	}
	
	public String getName()
	{
		return name;
	}
	
	public long getId()
	{
		return id;
	}
	
	public Key getParent()
	{
		throw new RuntimeException("getParent should not be called on the client side...");
	}

}
