package com.google.appengine.api.users;

import com.google.gwt.user.client.rpc.IsSerializable;
import java.io.Serializable;

/**
 * @author Bryce Cottam 
 *
 */
public final class User implements Serializable, IsSerializable, Comparable<User>
{

	private String email;
	private String authDomain;
    
	public User(String email, String authDomain)
	{
		if(email == null)
		{
			throw new NullPointerException("email must be specified");
		}
		if(authDomain == null)
		{
			throw new NullPointerException("authDomain must be specified");
		}
		
		this.email = email;
		this.authDomain = authDomain;
	}

	public String getNickname()
	{
		String nickname = email;
		
		int indexOfDomain = email.indexOf((new StringBuilder()).append("@").append(authDomain).toString());
		if(indexOfDomain > -1)
		{
			nickname = email.substring(0, indexOfDomain);
		}
		
		return nickname;
	}

	public String getAuthDomain()
	{
		return authDomain;
	}

	public String getEmail()
	{
		return email;
	}

	public String toString()
	{
		return email;
	}

	public boolean equals(Object object)
	{
		boolean eq = false;
		
		if(object instanceof User)
		{
			User that = (User)object;
			eq = that.email.equals(((Object) (email))) && that.authDomain.equals(((Object) (authDomain)));
		}
		
		return eq;
	}

	public int hashCode()
	{
		return email.hashCode() ^ authDomain.hashCode();
	}

	public int compareTo(User user)
	{
		return email.compareTo(user.email);
	}
	
}
